@@ -1,4 +1,4 @@
-# $Id: ODBC.pm 10404 2007-12-11 08:51:16Z mjevans $
+# $Id: ODBC.pm 11256 2008-05-12 14:20:24Z mjevans $
 #
 # Copyright (c) 1994,1995,1996,1998  Tim Bunce
 # portions Copyright (c) 1997-2004  Jeff Urlwin
@@ -9,7 +9,7 @@
 
 require 5.006;
 
-$DBD::ODBC::VERSION = '1.15';
+$DBD::ODBC::VERSION = '1.16';
 
 {
     package DBD::ODBC;
@@ -17,10 +17,10 @@ $DBD::ODBC::VERSION = '1.15';
     use DBI ();
     use DynaLoader ();
     use Exporter ();
-    
+
     @ISA = qw(Exporter DynaLoader);
 
-    # my $Revision = substr(q$Id: ODBC.pm 10404 2007-12-11 08:51:16Z mjevans $, 13,2);
+    # my $Revision = substr(q$Id: ODBC.pm 11256 2008-05-12 14:20:24Z mjevans $, 13,2);
 
     require_version DBI 1.21;
 
@@ -31,6 +31,17 @@ $DBD::ODBC::VERSION = '1.15';
     $sqlstate = "00000";
     $drh = undef;	# holds driver handle once initialised
 
+    sub parse_trace_flag {
+        my ($class, $name) = @_;
+        return 0x01000000 if $name eq 'odbcdev';
+        return DBI::parse_trace_flag($class, $name);
+    }
+
+    sub parse_trace_flags {
+        my ($class, $flags) = @_;
+        return DBI::parse_trace_flags($class, $flags);
+    }
+
     sub driver{
 	return $drh if $drh;
 	my($class, $attr) = @_;
@@ -86,6 +97,11 @@ $DBD::ODBC::VERSION = '1.15';
 {   package DBD::ODBC::db; # ====== DATABASE ======
     use strict;
 
+    sub parse_trace_flag {
+        my ($h, $name) = @_;
+        return DBD::ODBC->parse_trace_flag($name);
+    }
+
     sub private_attribute_info {
         return {
                 odbc_ignore_named_placeholders => undef, # sth and dbh
@@ -136,7 +152,7 @@ $DBD::ODBC::VERSION = '1.15';
 
 	$sth;
     }
-    
+
     sub columns {
 	my ($dbh, $catalog, $schema, $table, $column) = @_;
 
@@ -180,10 +196,10 @@ $DBD::ODBC::VERSION = '1.15';
 
     sub primary_key_info {
        my ($dbh, $catalog, $schema, $table ) = @_;
- 
+
        # create a "blank" statement handle
        my $sth = DBI::_new_sth($dbh, { 'Statement' => "SQLPrimaryKeys" });
- 
+
        $catalog = "" if (!$catalog);
        $schema = "" if (!$schema);
        $table = "" if (!$table);
@@ -192,12 +208,30 @@ $DBD::ODBC::VERSION = '1.15';
        $sth;
     }
 
+    sub statistics_info {
+       my ($dbh, $catalog, $schema, $table, $unique, $quick ) = @_;
+
+       # create a "blank" statement handle
+       my $sth = DBI::_new_sth($dbh, { 'Statement' => "SQLStatistics" });
+
+       $catalog = "" if (!$catalog);
+       $schema = "" if (!$schema);
+       $table = "" if (!$table);
+       $unique = 1 if (!$unique);
+       $quick = 1 if (!$quick);
+
+       DBD::ODBC::st::_statistics($dbh, $sth, $catalog, $schema, $table,
+                                 $unique, $quick)
+	     or return undef;
+       $sth;
+    }
+
     sub foreign_key_info {
        my ($dbh, $pkcatalog, $pkschema, $pktable, $fkcatalog, $fkschema, $fktable ) = @_;
- 
+
        # create a "blank" statement handle
        my $sth = DBI::_new_sth($dbh, { 'Statement' => "SQLForeignKeys" });
- 
+
        $pkcatalog = "" if (!$pkcatalog);
        $pkschema = "" if (!$pkschema);
        $pktable = "" if (!$pktable);
@@ -375,7 +409,7 @@ $DBD::ODBC::VERSION = '1.15';
 	_GetSpecialColumns($dbh, $sth, $Identifier, $Catalog, $Schema, $Table, $Scope, $Nullable) or return undef;
 	$sth;
     }
-	
+
     sub GetTypeInfo {
 	my ($dbh, $sqltype) = @_;
 	# create a "blank" statement handle
@@ -403,6 +437,8 @@ $DBD::ODBC::VERSION = '1.15';
 {   package DBD::ODBC::st; # ====== STATEMENT ======
     use strict;
 
+    *parse_trace_flag = \&DBD::ODBC::db::parse_trace_flag;
+
     sub private_attribute_info {
         return {
                 odbc_ignore_named_placeholders => undef, # sth and dbh
@@ -451,8 +487,8 @@ Please note that the change log has been moved to
 DBD::ODBC::Changes.pm. To access this documentation, use
 C<perldoc DBD::ODBC::Changes>.
 
-For FAQs see L</Frequently Asked Questions> or
-L<http://dbi.perl.org>.
+The FAQs have also moved to DBD::ODBC::FAQ.pm. To access the FAQs use
+C<perldoc DBD::ODBC::FAQ>.
 
 =head2 Important note about the tests
 
@@ -546,13 +582,27 @@ the L</odbc_err_handler> and t/20SQLServer.t for an example of this.
 
 =head3 odbc_query_timeout
 
-This allows the end user to set a timeout for queries on the ODBC
-side.  Add
+This allows you to change the ODBC query timeout (the ODBC statement
+attribute SQL_ATTR_QUERY_TIMEOUT). ODBC defines the query time out as
+the number of seconds to wait for a SQL statement to execute before
+returning to the application. A value of 0 (the default) means there
+is no time out. B<Do not confuse this with the ODBC attributes
+SQL_ATTR_LOGIN_TIMEOUT and SQL_ATTR_CONNECTION_TIMEOUT>. Add
 
   { odbc_query_timeout => 30 }
 
-to you connect or set on the dbh before executing the statement. The
-default is 0, no timeout.
+to your connect, set on the dbh before creating a statement or
+explicitly set it on your statement handle. The odbc_query_timeout on
+a statement is inherited from the parent connection.
+
+Note that internally DBD::ODBC only sets the query timeout if you set it
+explicitly and the default of 0 (no time out) is implemented by the
+ODBC driver and not DBD::ODBC.
+
+Note that some ODBC drivers implement a maximum query timeout value
+and will limit time outs set above their maximum. You may see a
+warning if your time out is capped by the driver but there is
+currently no way to retrieve the capped value back from the driver.
 
 Note that some drivers may not support this attribute.
 
@@ -827,11 +877,21 @@ or
 
 =head3 GetStatistics
 
+B<This private function is now superceded by DBI's statistics_info
+method.>
+
 See the ODBC specification for the SQLStatistics API.
 You call SQLStatistics like this:
 
   $dbh->func($catalog, $schema, $table, $unique, 'GetStatistics');
 
+Prior to DBD::ODBC 1.16 $unique was not defined as being true/false or
+SQL_INDEX_UNIQUE/SQL_INDEX_ALL. In fact, whatever value you provided
+for $unique was passed through to the ODBC API SQLStatistics call
+unchanged. This changed in 1.16, where $unique became a true/false
+value which is interpreted into SQL_INDEX_UNIQUE for true and
+SQL_INDEX_ALL for false.
+
 =head3 GetForeignKeys
 
 B<This private function is now superceded by DBI's foreign_key_info
@@ -843,7 +903,7 @@ You call SQLForeignKeys like this:
   $dbh->func($pcatalog, $pschema, $ptable,
              $fcatalog, $fschema, $ftable,
              "GetForeignKeys");
- 
+
 =head3 GetPrimaryKeys
 
 B<This private function is now superceded by DBI's primary_key_info
@@ -852,7 +912,7 @@ method.>
 See the ODBC specification for the SQLPrimaryKeys API.
 You call SQLPrimaryKeys like this:
 
-  $dbh->func($vatalog, $schema, $table, "GetPrimaryKeys");
+  $dbh->func($catalog, $schema, $table, "GetPrimaryKeys");
 
 =head3 data_sources
 
@@ -874,7 +934,7 @@ You call SQLSpecialColumns like this:
              $nullable, 'GetSpecialColumns');
 
 Handled as of version 0.28
- 
+
 head3 ColAttributes
 
 B<This private function is now superceded by DBI's statement attributes
@@ -898,6 +958,82 @@ You call SQLDescribeCol like this:
 The returned array contains the column attributes in the order described
 in the ODBC specification for SQLDescribeCol.
 
+=head2 Tracing
+
+DBD::ODBC now supports the parse_trace_flag and parse_trace_flags
+methods introduced in DBI 1.42 (see DBI for a full description).  As
+of DBI 1.604, the only trace flag defined which is relevant to
+DBD::ODBC is 'SQL' which DBD::ODBC supports by outputting the SQL
+strings (after modification) passed to the prepare and do methods.
+
+Currently DBD::ODBC only supports one private trace flag.  The
+'odbcdev' trace flag is used to output development tracing so it
+should not be relevant in normal use.
+
+To enable tracing of particular flags you use:
+
+  $h->trace($h->parse_trace_flags('SQL|odbcdev'));
+  $h->trace($h->parse_trace_flags('1|odbcdev'));
+
+In the first case 'SQL' and 'odbcdev' tracing is enabled on $h. In the
+second case trace level 1 is set and 'odbcdev' tracing is enabled.
+
+If you want to enable a DBD::ODBC private trace flag before connecting
+you need to do something like:
+
+  use DBD::ODBC;
+  DBI->trace(DBD::ODBC->parse_trace_flag('odbcdev');
+
+DBD::ODBC outputs tracing at levels 3 and above (as levels 1 and 2 are
+reserved for DBI).
+
+=head2 Deviations from the DBI specification
+
+=head3 Mixed placeholder types
+
+There are 3 conventions for place holders in DBI. These are '?', ':N'
+and ':name' (where 'N' is a number and 'name' is an alpha numeric
+string not beginning with a number). DBD::ODBC supports all these methods
+for naming placeholders but you must only use one method throughout
+a particular SQL string. If you mix placeholder methods you will get
+an error like:
+
+  Can't mix placeholder styles (1/2)
+
+=head3 Using the same placeholder more than once
+
+DBD::ODBC does not support (currently) the use of one placeholder
+more than once in the a single SQL string. i.e.,
+
+  insert into foo values (:bar, :p1, :p2, :bar);
+
+is not supported because 'bar' is used more than once but:
+
+  insert into foo values(:bar, :p1, :p2)
+
+is ok. If you do the former you will get an error like:
+
+  DBD::ODBC does not yet support binding a named parameter more than once
+
+=head3 Binding named placeholders
+
+Although the DBI documentation (as of 1.604) does not say how named
+parameters are bound Tim Bunce has said that in Oracle they are bound
+with the leading ':' as part of the name and that has always been the
+case. i.e.,
+
+  prepare("insert into mytable values (:fred)");
+  bind_param(":foo", 1);
+
+DBD::ODBC does not support binding named parameters with the ':' introducer.
+In the above example you must use:
+
+  bind_param("foo", 1);
+
+In discussion on the dbi-dev list is was suggested that the ':' could
+be made optional and there were no basic objections but it has not
+made it's way into the pod yet.
+
 =head2 Others/todo?
 
 Level 1
@@ -920,7 +1056,7 @@ The ability to connect without a full DSN is introduced in version
 
 Example (using MS Access):
 	my $DSN = 'driver=Microsoft Access Driver (*.mdb);dbq=\\\\cheese\\g$\\perltest.mdb';
-	my $dbh = DBI->connect("dbi:ODBC:$DSN", '','') 
+	my $dbh = DBI->connect("dbi:ODBC:$DSN", '','')
 		or die "$DBI::errstr\n";
 
 =head2 Using DBD::ODBC with web servers under Win32.
@@ -984,13 +1120,13 @@ The ability to connect without a full DSN is introduced in version 0.21.
 Example (using MS Access):
 	my $DSN = 'driver=Microsoft Access Driver
 (*.mdb);dbq=\\\\cheese\\g$\\perltest.mdb';
-	my $dbh = DBI->connect("dbi:ODBC:$DSN", '','') 
+	my $dbh = DBI->connect("dbi:ODBC:$DSN", '','')
 		or die "$DBI::errstr\n";
 
 The above sample uses Microsoft's UNC naming convention to point to the MSAccess
 file (\\\\cheese\\g$\\perltest.mdb).  The dbq parameter tells the access driver
 which file to use for the database.
-   
+
 Example (using MSSQL Server):
       my $DSN = 'driver={SQL Server};Server=server_name;
       database=database_name;uid=user;pwd=password;';
@@ -1003,12 +1139,25 @@ Example (using MSSQL Server):
 These are in need of sorting and annotating. Some are relevant only
 to ODBC developers.
 
+You can find DBD::ODBC on ohloh now at:
+
+L<http://www.ohloh.net/projects/perl_dbd_odbc>
+
+There is a good search engine for the various Perl DBI lists at the
+following URLS:
+
+L<http://perl.markmail.org/search/list:org.perl.dbi-users>
+
+L<http://perl.markmail.org/search/list:org.perl.dbi-dev>
+
+L<http://perl.markmail.org/search/list:org.perl.dbi-announce>
+
 L<http://www.syware.com>
 
 L<http://www.microsoft.com/odbc>
 
 For Linux/Unix folks, compatible ODBC driver managers can be found at:
-   
+
 L<http://www.unixodbc.org> (unixODBC source and rpms)
 
 L<http://www.iodbc.org> (iODBC driver manager source)
@@ -1023,7 +1172,7 @@ L<http://www.openlinksw.com>
 L<http://www.datadirect.com>
 
 L<http://www.atinet.com/support/openrda_samples.asp>
- 
+
 Some useful tutorials:
 
 Debugging Perl DBI:
@@ -1053,324 +1202,7 @@ L<http://www.easysoft.com/developer/languages/perl/tutorial_data_web.html>
 
 =head2 Frequently Asked Questions
 
-Answers to common DBI and DBD::ODBC questions:
-
-=over
-
-=item How do I read more than N characters from a Memo | BLOB | LONG field?
-
-See LongReadLen in the DBI docs.
-
-Example:
-
- $dbh->{LongReadLen} = 20000;
- $sth = $dbh->prepare("select long_col from big_table");
- $sth->execute;
- etc
-
-=item What is DBD::ODBC?
-
-=item Why can't I connect?
-
-=item Do I need an ODBC driver?
-
-=item What is the ODBC driver manager?
-
-These, general questions lead to needing definitions.
-
-=over 4
-
-=item ODBC Driver
-
-The ODBC Driver is the driver that the ODBC manager uses to connect
-and interact with the RDBMS.  You B<DEFINITELY> need this to connect to
-any database.  For Win32, they are plentiful and installed with many
-applications.  For Linux/Unix, you can find a fairly comprehensive list
-at L<http://www.unixodbc.org/drivers.html>.
-
-=item ODBC Driver Manager
-
-The ODBC driver manager is the interface between an ODBC application
-(DBD::ODBC in this case) and the ODBC driver. The driver manager
-principally provides the ODBC API so ODBC applications may link with a
-single shared object (or dll) and be able to talk to a range of ODBC
-drivers. At run time the application provides a connection string
-which defines the ODBC data source it wants to connect to and this in
-turn defines the ODBC driver which will handle this data source. The
-driver manager loads the requested ODBC driver and passes all ODBC API
-calls on to the driver. In this way, an ODBC application can be built
-and distributed without knowing which ODBC driver it will be using.
-
-However, this is a rather simplistic description of what the driver
-manager does. The ODBC driver manager also:
-
-* Controls a repository of installed ODBC drivers (on UNIX this is the
-file odbcinst.ini).
-
-* Controls a repository of defined ODBC data sources (on UNIX these are
-the files odbc.ini and .odbc.ini).
-
-* Provides the ODBC driver APIs (SQLGetPrivateProfileString and
-SQLWritePrivateProfileString) to read and write ODBC data source
-attributes.
-
-* Handles ConfigDSN which the driver exports to configure data
-sources.
-
-* Provides APIs to install and uninstall drivers (SQLInstallDriver).
-
-* Maps ODBC versions e.g. so an ODBC 2.0 application can work with an
-ODBC 3.0 driver and vice versa.
-
-* Maps ODBC states between different versions of ODBC.
-
-* Provides a cursor library for drivers which only support
-forward-only cursors.
-
-* Provides SQLDataSources and SQLDrivers so an application can find
-out what ODBC drivers are installed and what ODBC data sources are
-defined.
-
-* Provides an ODBC administrator which driver writers can use to
-install ODBC drivers and users can use to define ODBC data sources.
-
-The ODBC Driver Manager is the piece of software which interacts with
-the drivers for the application.  It "hides" some of the differences
-between the drivers (i.e. if a function call is not supported by a
-driver, it 'hides' that and informs the application that the call is
-not supported.  DBD::ODBC needs this to talk to drivers.
-
-Under Win32, you usually get the ODBC Driver Manager as part of the
-OS.  Under Unix/Linux you may have to find and build the driver
-manager yourself. The two main driver managers for Unix are unixODBC
-(L<http://www.unixodbc.org>) and iODBC (L<http://www.iodbc.org>).
-
-B<It is strongly advised you get an ODBC Driver Manager before trying to
-build DBD::ODBC unless you intend linking DBD::ODBC directly with your
-driver.>
-
-For a reasonable description of ODBC on Unix/Linux see
-L<http://www.easysoft.com/developer/interfaces/odbc/linux.html>
-
-=item DBD::ODBC
-
-DBD::ODBC uses the driver manager to talk to the ODBC driver(s) on
-your system.  You need both a driver manager and driver installed and
-tested before working with DBD::ODBC.  You need to have a DSN (see
-below) configured and B<TESTED> before being able to test DBD::ODBC.
-
-=item DSN (Data Source Name)
-
-
-The DSN is a way of referring to a particular driver and database by
-any name you wish.  The DSN is usually a key to a list of attributes
-the ODBC driver needs to connect to the database (e.g. ip address and
-port) but there is always a key which names the driver so the driver
-manager knows which driver to use with which data source. Do no
-confuse DSNs with ODBC connection strings or DBI's "$data_source" (the
-first argument to L<DBI/connect>.
-
-The $data_source argument to DBI is composed of 'dbi:DRIVER:something_else'
-where DRIVER is the name of the DBD driver you want to use (ODBC of
-course for DBD::ODBC). The "something_else" for DBD::ODBC can be a DSN
-name or it can be a normal ODBC connection string.
-
-An ODBC connection string consists of attribute/value pairs separated
-with semicolons (;). You can replace "something_else" above with a
-normal ODBC connection string but as a special case for DBD::ODBC you can
-just use the DSN name without the usual ODBC connection string prefix
-of "DSN=dsn_name".
-
-e.g.
-
-=over
-
-=item dbi:ODBC:DSN=fred
-
-ODBC connection string using fred DSN
-
-=item dbi:ODBC:fred
-
-Same as above (a special case).
-
-=item dbi:ODBC:Driver={blah blah driver};Host=1.2.3.4;Port=1000;
-
-This is known as a DSN-less connection string for obvious reasons.
-
-=back
-
-=back
-
-=item Where do I get an ODBC driver manager for Unix/Linux?
-
-DBD::ODBC used to come bundled with a driver manager but this became
-inconvenient when the driver manager was updated.
-
-The two main ODBC Driver Managers for Unix are unixODBC (L<http://www.unixodbc/org>) and iODBC (L<http://www.iodbc.org>).
-
-If you are running a packaged Linux like RedHat, Ubuntu, Fedora, Suse
-etc etc you'll usually find it packaged with unixODBC and using the
-package manager to install it is fairly straight forward. However,
-make sure that if the driver manager is split into multiple packages
-you install the development package as well as that contains the C
-header files required by DBD::ODBC.
-
-If you cannot find an ODBC Driver Manager package for your OS you can
-download the source tar files for either of the driver managers above
-and build it yourself.
-
-=item How do I access a MS SQL Server database from Linux/UNIX?
-
-You have loads of choices (in no particular order):
-
-* using DBI::ProxyServer or DBD::Gofer. You'll need the former if you
-  use transactions.
-
-* using a commercial ODBC Driver or bridge like the ones from Easysoft
-or Openlink.
-
-* using FreeTDS an open source TDS library which includes an ODBC Driver.
-
-* using DBD::Sybase and Sybase libraries.
-
-=item How do I access a MS-Access database from Linux?
-
-There are basically two choices:
-
-* a commercial ODBC Bridge like the ones from Easysoft or OpenLink.
-
-* using mdbtools although as of writing it has not been updated since
-June 2004, only provides read access and seems to be a little buggy.
-
-=item Almost all of my tests for DBD::ODBC fail. They complain about
-not being able to connect or the DSN is not found.
-
-Please, please test your configuration of ODBC and driver before
-trying to test DBD::ODBC. Most of the time, this stems from the fact
-that the DSN (or ODBC) is not configured properly. unixODBC comes with
-a small program isql and iODBC comes with odbctest and you should use
-these to test your ODBC configuration is working properly first.
-
-=item I'm attempting to bind a Long Var char (or other specific type)
-and the binding is not working.
-
-The code I'm using is below:
-
-	$sth->bind_param(1, $str, $DBI::SQL_LONGVARCHAR);
-                                 ^^^
-
-The problem is that DBI::SQL_LONGVARCHAR is not the same as
-$DBI::SQL_LONGVARCHAR and that $DBI::SQL_LONGVARCHAR is an error!
-
-It should be:
-
-	$sth->bind_param(1, $str, DBI::SQL_LONGVARCHAR);
-
-=item Does DBD::ODBC support Multiple Active Statements?
-
-Multiple Active Statements (MAS) are concurrent statements created
-from the same database handle which both have pending actions on them
-(e.g. they both have executed a select statement but not retrieved all
-the available rows yet).
-
-DBD::ODBC does support MAS but whether you can actually use MAS is
-down to the ODBC Driver.
-
-By default MS SQL Server did not used to support multiple active
-statements if any of them were select statements. You could get around
-this (with caution) by changing to a dynamic cursor. There is a "hack"
-in DBD::ODBC which can be used to enable MAS but you have to fully
-understand the implications of doing so(see
-L<DBD/ODBC/odbc_SQL_ROWSET_SIZE> and L<DBD/ODBC/odbc_cursortype>).
-
-In MS SQL Server 2005, there is a new thing called MARS (Multiple
-Active Result Sets) which allows multiple active select statements but
-it has some nasty implications it you are also doing transactions.
-
-For other drivers it depends. I believe various Oracle ODBC drivers
-doe support multiple active statements as myodbc does.
-
-Think carefully before using multiple active statements. It is
-probably not portable and there is nearly always a better way of doing
-it.
-
-If anyone wants to report success with a particular driver and
-multiple active statements I will collect them here.
-
-=item Why do I get "Datetime field overflow" when attempting to insert a
-date into Oracle?
-
-If you are using the Oracle or Microsoft ODBC drivers then you may get
-the following error when inserting dates into an Oracle database:
-
-  [Oracle][ODBC]Datetime field overflow. (SQL-22008)
-
-If you do then check v$nls_parameters and v$parameter to see if you are
-using a date format containing the RR format. e.g.,
-
-  select * from v$nls_parameters where parameter = 'NLS_DATE_FORMAT'
-  select * from v$parameter where name = 'nls_date_format'
-
-If you see a date format like 'DD-MON-RR' (e.g., contains an RR) then
-all I can suggest is you change the date format for your session as I
-have never been able to bind a date using this format. You can do this
-with:
-
-  alter session set nls_date_format='YYYY/MM/DD'
-
-and use any format you like but keep away from 'RR'.
-
-You can find some test code in the file mytest/rtcpan_28821.pl which
-demonstrates this problem. This was originally a rt.cpan issue which
-can be found at L<http://rt.cpan.org/Ticket/Display.html?id=28821>.
-
-As an aside, if anyone is reading this and can shed some light on the problem
-I'd love to hear from you. The technical details are:
-
-  create table rtcpan28821 (a date)
-  insert into rtcpan28821 values('23-MAR-62') fails
-
-Looking at the ODBC trace, SQLDescribeParam returns:
-
-  data type: 93, SQL_TYPE_TIMESTAMP
-  size: 19
-  decimal digits: 0
-  nullable: 1
-
-and DBD::ODBC calls SQLBindParameter with:
-
-  ValueType: SQL_C_CHAR
-  ParameterType: SQL_TYPE_TIMESTAMP
-  ColumnSize: 9
-  DecimalDigits: 0
-  Data: 23-MAR-62
-  BufferLength: 9
-
-=item Why do my SQL Server temporary objects disappear?
-
-If you are creating temporary objects (e.g., temporary tables) in
-SQL Server you find they have disappeared when you attempt to use
-them. Temporary objects only have a lifetime of the session they
-are created in but in addition, they cannot be created using
-prepare/execute. e.g., the following fails:
-
-  $s = $h->prepare('select * into #tmp from mytable');
-  $s->execute;
-  $s = $h->selectall_arrayref('select * from #tmp');
-
-with "Invalid object name '#tmp'". Your should read
-L<http://technet.microsoft.com/en-US/library/ms131667.aspx> which
-basically says I<Prepared statements cannot be used to create
-temporary objects on SQL Server 2000 or later...>. The proper way to
-avoid this is to use the C<do> method but if you cannot do that then
-you need to add the L</odbc_exec_direct> attribute to your prepare as
-follows:
-
-  my $s = $h->prepare('select * into #tmp from mytable',
-                      { odbc_exec_direct => 1});
-
-See L</odbc_exec_direct>.
-
-=back
+Frequently asked questions are now in DBD::ODBC::FAQ. Run
+C<perldoc DBD::ODBC::FAQ> to view them.
 
 =cut
